@@ -1,5 +1,6 @@
+#modified April 29th to get around the problem of missing rows or columns in the polychoric function.
 "mixed.cor" <- 
-function(x=NULL,p=NULL,d=NULL,smooth=TRUE,ncat=8)  {
+function(x=NULL,p=NULL,d=NULL,smooth=TRUE,correct=TRUE,global=TRUE,ncat=8,polycor=FALSE)  {
 cl <- match.call() 
 organize <- FALSE   #the default is to specify the continuous, the polytomous and the dichotomous
 if(!is.null(x) && is.null(p)  && is.null(d)) { #figure out which kinds of variables we are using 
@@ -19,11 +20,11 @@ if(length(pvars) > 0) {p <- matrix(x[,pvars],ncol=length(pvars))
  if(length(cvars) > 0) {cont <- matrix(x[,cvars],ncol=length(cvars))
                        colnames(cont) <- colnames(x)[cvars] } else {cont <- NULL}
                        
-Rho <- mixed.cor1(cont,p, d)
+Rho <- mixed.cor1(cont,p, d,smooth=smooth,polycor=polycor,global=global,correct=correct)
 oldorder <- c(cvars,pvars,dvars)
 ord <- order(oldorder)
 Rho$rho <- Rho$rho[ord,ord]
-} else {Rho <- mixed.cor1(x=x,p=p,d=d,smooth=smooth)}
+} else {Rho <- mixed.cor1(x=x,p=p,d=d,smooth=smooth,polycor=polycor,global=global,correct=correct)}
 
 Rho$Call <- cl
 return(Rho)
@@ -34,7 +35,7 @@ return(Rho)
 #meant to combine continuous, polytomous and dichotomous correlations
 #revised October 12, 2011 to get around the sd of vectors problem
 "mixed.cor1" <-
-function(x=NULL,p=NULL,d=NULL,smooth=TRUE) {
+function(x=NULL,p=NULL,d=NULL,smooth=TRUE,polycor=FALSE,global=TRUE,correct=TRUE) {
  cl <- match.call() 
 if(!is.null(x)) {nx <- dim(x)[2]} else {nx <- 0}
 if(!is.null(p)) {np <- dim(p)[2]} else {np <- 0}
@@ -58,13 +59,13 @@ if(nx > 0) {rx <- cor(x,use="pairwise")} else {rx <- NULL
    rho <- NULL}
 if(np > 1) {
 #cat("\n Starting to find the polychoric correlations")
- rp <- polychoric(p,smooth=smooth)}    else {if (np == 1) {
+ rp <- polychoric(p,smooth=smooth,polycor=polycor,global=global)}    else {if (np == 1) {
 	rho <- 1
 	names(rho) <- colnames(p)
 	rp <- list(rho=rho,tau=NULL)}  else {rp <- list(rho= NULL,tau=NULL)}}
 if(nd > 1) {
  #cat("n Starting to find the tetrachoric correlations\n\n")
-  rd <- tetrachoric(d,smooth=smooth)}   else {if (nd == 1) {rd <- list(rho=1,tau=NULL)}  else {rd <- list(rho=NULL,tau=NULL)}}
+  rd <- tetrachoric(d,smooth=smooth,correct=correct)}   else {if (nd == 1) {rd <- list(rho=1,tau=NULL)}  else {rd <- list(rho=NULL,tau=NULL)}}
 
 if(nx > 0) {if(np > 0) {rxp <- polyserial(x,p)   #the normal case is for all three to exist
 		tmixed <- cbind(rx,t(rxp))
